DataContract<T> class abstract

Outline of core methods to which all data loaders must adhere.

Mixed-in types
Implementers

Constructors

DataContract()
Outline of core methods to which all data loaders must adhere.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedOperations Set<SourceOperationType>
The operations supported by this loader instance. Defaults to standard CRUD operations.
no setter

Methods

delete(DeleteOperation<T> operation) Future<DeleteResult<T>>
Clears an item with the given DeleteOperation.itemId if one exists.
inherited
getById(ReadOperation<T> operation) Future<ReadResult<T>>
Loads the instance of T whose primary key is found at ReadOperation.itemId.
inherited
getByIds(ReadByIdsOperation<T> operation) Future<ReadListResult<T>>
Loads all instances of T whose primary key is in the set at ReadByIdsOperation.itemIds.
inherited
getItems(ReadListOperation<T> operation) Future<ReadListResult<T>>
Loads all instances of T that satisfy any filtes or pagination on ReadListOperation.details.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setItem(WriteOperation<T> operation) Future<WriteResult<T>>
Persists WriteOperation.item.
inherited
setItems(WriteListOperation<T> operation) Future<WriteListResult<T>>
Persists all WriteListOperation.items.
inherited
supports(SourceOperationType type) bool
Returns whether this instance supports the given SourceOperationType.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited