MessageWriteMixin<T> mixin

Introduces message operations for creation and generic updates.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(SendMessageOperation<T> operation) Future<WriteResult<T>>
Sends a message object (e.g. for patching or decoupled creations).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited