sourceType property
Indicator for whether this Source loads data from a store on-device, or off-device.
Implementation
@override
SourceType get sourceType => SourceType.remote;
Indicator for whether this Source loads data from a store on-device, or off-device.
@override
SourceType get sourceType => SourceType.remote;