AuthenticatedReadApiRequest class

Read requests that require user authentication to complete successfully.

Inheritance

Constructors

AuthenticatedReadApiRequest({required Object? user, required ApiUrl url, Headers headers = const {}, Params? params})
Read requests that require user authentication to complete successfully.
const

Properties

contentType → String
Default content type header.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
Finalized headers, combining starter headers with the builder method.
no setterinherited
params → Params?
GET/querystring-style payload of this request.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → ApiUrl
Destination of this request.
finalinherited
user → Object?
Whatever data is needed to authenticate this request.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited