ComboFilter class

Specialized filter meant to combine multiple children filters.

Inheritance

Constructors

ComboFilter(List<Filter> children, BooleanLogic logic)
Specialized filter meant to combine multiple children filters.
const

Properties

cacheKey CacheKey
Variant of hashCode with persistent Ids across application launches.
no setteroverride
children List<Filter>
Nested filters to be evaluated.
final
hashCode int
The hash code for this object.
no setterinherited
logic BooleanLogic
Governing logic for how many of children must pass.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Json
Serializes this Filter full-stack Dart endpoints.
override
toParams() Params
Query parameters form of this filter to be included in an ApiRequest and applied by the server.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited