MatchedSource<T> class

Indicates whether a given Source was queried within a request, which is used when during the write-through cache phase.

Constructors

MatchedSource.matched(Source<T> source)
Flavor of Source that matched the given RequestType. This Source will be asked for the desired data.
factory
MatchedSource.unmatched(Source<T> source)
Flavor of Source that did not match the given RequestType. This Source will not be asked for the desired data and will only be able to cache the results of another Source, if appropriate.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
matched bool
Whether or not this Source matched the given RequestType.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Source<T>
final
unmatched bool
Opposite of matched.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited