performInitialization abstract method

FutureOr<void> performInitialization()

Classes using ReadinessMixin should implement this method to perform any necessary initialization. Implementations of this method should call markReady and pass in any special value for T that should be returned from ready.

Implementation

FutureOr<void> performInitialization();