resetReadiness method

  1. @mustCallSuper
void resetReadiness()

Resets any established readiness, if for example a dependency of this object has also lost readiness.

A common use case to call this method is for anything that marks itself ready once a user session is established; after that user logs out.

Implementation

@mustCallSuper
void resetReadiness() {
  _log.finest('Resetting readiness for $this');
  _readinessCompleter = Completer<T>();
  _hasCalledInitialize = false;
  readiness = Readiness.loading;
}