RequestDelegate.live constructor
const
RequestDelegate.live()
Live RequestDelegate which uses the http library to make real
network requests.
Implementation
const factory RequestDelegate.live() = _LiveRequestDelegate;
Live RequestDelegate which uses the http library to make real
network requests.
const factory RequestDelegate.live() = _LiveRequestDelegate;