forceInsert property

bool forceInsert
final

Tells sources, especially remote sources, to insert this data even though it may already have an Id. This can be paired with CreationBindings which assign Ids on the client.

Implementation

final bool forceInsert;