sourceType property
SourceType
get
sourceType
Indicator for whether this Source loads data from a store on-device, or off-device.
Implementation
SourceType get sourceType;
Indicator for whether this Source loads data from a store on-device, or off-device.
SourceType get sourceType;