bindings property
Holds meta-information for a subclass of data class, making it fully pluggable within any subtype of DataContract.
Implementation
final Bindings<T> bindings;
Holds meta-information for a subclass of data class, making it fully pluggable within any subtype of DataContract.
final Bindings<T> bindings;