WatchableSource<T> mixin

Optional mixin for Source classes indicating they are capable of opening live data subscriptions (e.g. websockets, polling intervals, Firebase snapshots) to stream ongoing results matching a given reading Operation.

Superclass constraints

Properties

bindings ↔ Bindings<T>
All meta information about T necessary to plug arbitrary data types into a Repository.
getter/setter pairinherited
hasBindings → bool
Proxy getter for whether bindings has been initialized, either by being passed in via this constructor or by being set by the SourceList.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → SourceType
Indicator for whether this Source loads data from a store on-device, or off-device.
no setterinherited
supportedOperations → Set<SourceOperationType>
The operations supported by this loader instance. Defaults to standard CRUD operations.
no setteroverride

Methods

deleteItem(DeleteOperation<T> operation) → Future<DeleteResult<T>>
Clears an item with the given DeleteOperation.itemId if one exists.
inherited
deleteItems(DeleteListOperation<T> operation) → Future<DeleteResult<T>>
Clears all items matching the given DeleteListOperation.details.
inherited
getById(ReadOperation<T> operation) → Future<ReadResult<T>>
Loads the instance of T whose primary key is found at ReadOperation.itemId.
inherited
getByIds(ReadByIdsOperation<T> operation) → Future<ReadListResult<T>>
Loads all instances of T whose primary key is in the set at ReadByIdsOperation.itemIds.
inherited
getItems(ReadListOperation<T> operation) → Future<ReadListResult<T>>
Loads all instances of T that satisfy any filtes or pagination on ReadListOperation.details.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setItem(WriteOperation<T> operation) → Future<WriteResult<T>>
Persists WriteOperation.item.
inherited
setItems(WriteListOperation<T> operation) → Future<WriteListResult<T>>
Persists all WriteListOperation.items.
inherited
supports(SourceOperationType type) → bool
Returns whether this instance supports the given SourceOperationType.
inherited
toString() → String
A string representation of this object.
inherited
watch(WatchOperation<T> operation) → Stream<ReadResult<T>>
Opens a live stream which will yield the current matching model periodically via a ReadResult.
watchByIds(WatchByIdsOperation<T> operation) → Stream<ReadListResult<T>>
Opens a live stream which will yield the current matching models periodically via a ReadListResult.
watchList(WatchListOperation<T> operation) → Stream<ReadListResult<T>>
Opens a live stream which will yield the current matching models periodically via a ReadListResult.

Operators

operator ==(Object other) → bool
The equality operator.
inherited