WriteApiRequest class

Subtype of ApiRequest for write, or POST/PATCH/PUT requests. Along with having one of those HTTP verbs, these requests also have request bodies and not querystrings.

Inheritance
Implementers

Constructors

WriteApiRequest({required ApiUrl url, required Json? body, Object? user, Headers headers = const {}, Params? params})
Subtype of ApiRequest for write, or POST/PATCH/PUT requests. Along with having one of those HTTP verbs, these requests also have request bodies and not querystrings.
const

Properties

body → Params?
Request payload in serialized JSON format.
final
contentType → String
Default content type header.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
Finalized headers, combining starter headers with the builder method.
no setterinherited
params → Params?
Optional query parameters for this request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → ApiUrl
Destination of this request.
finalinherited
user → Object?
Whatever data is needed to authenticate this request.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited