////////////////
DELETE RESULTS
////////////////
Outcome of an attempted delete operation. It may have succeeded, failed, or
had no chance due to connectivity issues.
A wrapper object used to safely pass a strongly-typed generic message
alongside its bindings through the dash_data_layer operation engine,
avoiding the limitations of Dart generic factory properties on Freezed
untyped objects.
A highly-typed adapter for a Repository that cleanly handles discrete
message/patch types (e.g. Freezed unions) for sending creation or update
operations securely over an untyped boundary, before being transformed into
the principal T object.
//////////////
READ RESULTS
//////////////
Outcome of an attempted read operation. It may have succeeded, failed, or
had no chance due to connectivity issues.
{@template Source}
Parent type of all entries in a SourceList. Each Source subtype should
know how to load data from a particular place. The field sourceType
indicates whether that place is immediately accessible (and thus is a cache)
or is remotely accessible and thus is the source of truth.
{@endtemplate }
///////////////
WRITE RESULTS
///////////////
Outcome of an attempted write operation. It may have succeeded, failed, or
had no chance due to connectivity issues.
Optional mixin for Source classes indicating they are capable of opening
live data subscriptions (e.g. websockets, polling intervals, Firebase
snapshots) to stream ongoing results matching a given reading Operation.