ProxySource<T> class
- Inheritance
-
- Object
- DataContract<
T> - Source<
T> - ProxySource
Constructors
-
ProxySource({required Bindings<
T> ? bindings, required SourceType sourceType, GetById<T> ? getByIdHandler, GetByIds<T> ? getByIdsHandler, GetItems<T> ? getItemsHandler, SetItem<T> ? setItemHandler, SetItems<T> ? setItemsHandler, DeleteItem<T> ? deleteHandler})
Properties
-
bindings
↔ Bindings<
T> -
All meta information about
Tnecessary to plug arbitrary data types into a Repository.getter/setter pairinherited -
deleteHandler
→ DeleteItem<
T> ? -
If supplied, used to satisfy delete.
final
-
getByIdHandler
→ GetById<
T> ? -
If supplied, used to satisfy getById.
final
-
getByIdsHandler
→ GetByIds<
T> ? -
If supplied, used to satisfy getByIds.
final
-
getItemsHandler
→ GetItems<
T> ? -
If supplied, used to satisfy getItems.
final
- hasBindings → bool
-
Proxy getter for whether bindings has been initialized, either by being
passed in via this constructor or by being set by the SourceList.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setItemHandler
→ SetItem<
T> ? -
If supplied, used to satisfy setItem.
final
-
setItemsHandler
→ SetItems<
T> ? -
If supplied, used to satisfy setItems.
final
- sourceType → SourceType
-
Indicator for whether this Source loads data from a store on-device, or
off-device.
final
Methods
-
delete(
DeleteOperation< T> operation) → Future<DeleteResult< T> > -
Clears an item with the given
DeleteOperation.itemIdif one exists.override -
getById(
ReadOperation< T> operation) → Future<ReadResult< T> > -
Loads the instance of
Twhose primary key is found atReadOperation.itemId.override -
getByIds(
ReadByIdsOperation< T> operation) → Future<ReadListResult< T> > -
Loads all instances of
Twhose primary key is in the set atReadByIdsOperation.itemIds.override -
getItems(
ReadListOperation< T> operation) → Future<ReadListResult< T> > -
Loads all instances of
Tthat satisfy any filtes or pagination onReadListOperation.details.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setItem(
WriteOperation< T> operation) → Future<WriteResult< T> > -
Persists
WriteOperation.item.override -
setItems(
WriteListOperation< T> operation) → Future<WriteListResult< T> > -
Persists all
WriteListOperation.items.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited