cacheKey property
Collapses this request into a key suitable for local memory caching. This key should incorporate everything about this request EXCEPT the requestType, as that would create false-positive variance.
Implementation
late final CacheKey cacheKey = _getCacheKey();