ttl property
Duration after which cached data should be considered stale. Supplying a non-null value to this can force cache misses from local sources which contain data that is older than this duration.
Implementation
final Duration? ttl;
Duration after which cached data should be considered stale. Supplying a non-null value to this can force cache misses from local sources which contain data that is older than this duration.
final Duration? ttl;