RequestType enum
Classifier for a data request which tells a subtype of DataContract where to look for the desired data.
Values
- allLocal → const RequestType
-
Requests which should read all locally available records and not consider request caches.
- local → const RequestType
-
Requests which should not leave the application - aka, cache reads.
- refresh → const RequestType
-
Requests which must leave the application - aka, cache refreshes.
- global → const RequestType
-
Requests which can look anywhere and should accept the first data they find. This is typically the default RequestType.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
includes(
SourceType sourceType) → bool - Checks whether a given SourceType matches this RequestType.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RequestType> - A constant List of the values in this enum, in order of their declaration.