hasBindings property
bool
get
hasBindings
Proxy getter for whether bindings has been initialized, either by being passed in via this constructor or by being set by the SourceList.
Implementation
bool get hasBindings => _bindings != null;