retryPolicy property
Retry policy for this SourceList. If this is supplied, then operations which fail due to connectivity or server issues can be retried.
Implementation
final RetryPolicy<T>? retryPolicy;
Retry policy for this SourceList. If this is supplied, then operations which fail due to connectivity or server issues can be retried.
final RetryPolicy<T>? retryPolicy;