////////////////
DELETE RESULTS
////////////////
Outcome of an attempted delete operation. It may have succeeded, failed, or
had no chance due to connectivity issues.
//////////////
READ RESULTS
//////////////
Outcome of an attempted read operation. It may have succeeded, failed, or
had no chance due to connectivity issues.
{@template Source}
Parent type of all entries in a SourceList. Each Source subtype should
know how to load data from a particular place. The field sourceType
indicates whether that place is immediately accessible (and thus is a cache)
or is remotely accessible and thus is the source of truth.
{@endtemplate }
///////////////
WRITE RESULTS
///////////////
Outcome of an attempted write operation. It may have succeeded, failed, or
had no chance due to connectivity issues.
Optional mixin for Source classes indicating they are capable of opening
live data subscriptions (e.g. websockets, polling intervals, Firebase
snapshots) to stream ongoing results matching a given reading Operation.